@@ -1,6 +1,6 @@
-package Pod::Weaver::Plugin::TaskWeaver;
+package Pod::Weaver::Plugin::TaskWeaver 0.101629;
 # ABSTRACT: Dist::Zilla::Plugin::TaskWeaver's helper
-$Pod::Weaver::Plugin::TaskWeaver::VERSION = '0.101628';
+
 use Moose;
 with 'Pod::Weaver::Role::Dialect', 'Pod::Weaver::Role::Section';
 
@@ -117,7 +117,7 @@ Pod::Weaver::Plugin::TaskWeaver - Dist::Zilla::Plugin::TaskWeaver's helper
 
 =head1 VERSION
 
-version 0.101628
+version 0.101629
 
 =head1 DESCRIPTION
 
@@ -130,13 +130,23 @@ This is a Pod::Weaver plugin.  It functions as both a Dialect and a Section,
 although this is basically hackery to get things into the right order.  For
 more information consult the L<Dist::Zilla::Plugin::TaskWeaver> documentation.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
